@@ -197,8 +197,8 @@ class MatrixProductState:
         max_length = np.max([len(s_val) for s_val in s_vals])
         max_sval = np.max([np.max(s_val) for s_val in s_vals])
         min_sval = np.min([np.min(s_val) for s_val in s_vals])
-        
-        if min_sval == 0:
+
+        if min_sval < 1e-20:
             min_sval = 1e-20
 
         subplot_kwargs0 = {"ncols": len(s_vals),
